@@ -54,20 +54,11 @@ sub new {
 }
 
 sub log {
-    my $self  = shift;
+    my $self = shift;
     my $level = shift;
-
-    if ($self->{filter_caller}) {
-        my $caller = (caller(1+$Log::Handler::CALLER_LEVEL))[0];
-        return 1 if $caller !~ $self->{filter_caller};
-    } elsif ($self->{except_caller}) {
-        my $caller = (caller(1+$Log::Handler::CALLER_LEVEL))[0];
-        return 1 if $caller =~ $self->{except_caller};
-    }
-
-    my $output  = $self->{output};
+    my $output = $self->{output};
     my $message = { };
-    my $wanted  = { message => join(" ", grep defined, @_) };
+    my $wanted = { message => join(" ", grep defined, @_) };
 
     # The patterns must be generated for each output. The reason
     # is that each output can have their own time/date format
